####################################################################
#
#  Copyright(C), 2004, Enfold Systems, LLC
#
#
# Enfold Systems, LLC
# 4500 Montrose Blvd., Suite D
# Houston, Texas 77006 USA
# p. +1 713.942.2377 | f. +1 832.201.8856
# www.enfoldsystems.com
# info@enfoldsystems.com
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License as
# published by the Free Software Foundation; either version 2.1 of the
# License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
# License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this library; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
####################################################################

# Derived from:

#------------------------------------------------------------------------------
# Name:         OxWidgets.py
# Purpose:      Supplementary widgets for use in Oxfam content types
#
# Author:       Duncan Booth <duncan.booth@suttoncourtenay.org.uk>
#
# Created:      Thu Mar 26
# Copyright:    (c) 2004 Oxfam
# Licence:
#------------------------------------------------------------------------------

# by J Cameron Cooper
# Enfold Systems, LLC

""" PopupReferenceWidget

Author:
Duncan Booth, Mar 2004
duncan.booth@suttoncourtenay.org.uk

J Cameron Cooper, Oct 2004
jcc@jcameroncooper.com

Widget.py : define PopupReferenceWidget
"""

from Acquisition import aq_base, aq_parent
from Products.Archetypes.Widget import ReferenceWidget
from Products.Archetypes.Registry import registerWidget
from Products.CMFCore.utils import getToolByName

__all__ = ('PopupReferenceWidget',)

class PopupReferenceWidget(ReferenceWidget):
    _properties = ReferenceWidget._properties.copy()
    _properties.update({
        'macro' : "popupreference",
        'addable' : 0, # create createObject link for every addable type
        'destination' : None, # may be:
                              # - ".", context object;
                              # - None, any place where
                              #   Field.allowed_types can be added;
                              # - string path;
                              # - name of method on instance
                              #   (it can be a combination list);
                              # - a list, combining all item above;
                              # - a dict, where
                              #   {portal_type:<combination of the items above>}
                              # destination is relative to portal root

        'base_search' : None,      # dictionary suitable for passing to catalog search. Unused if None.
        'batch_size' : 50,         # number of result to display
        'initial_location' : '',   # path to specify location to start at for browse,
                                   #   in form suitable for 'restrictedTraverse'. Default: current location
        'query_first': True,       # when showing the popup initially, show the query
        })

#    def addableTypes(self, instance, field):
#        """Returns a dictionary which maps portal_type to its human readable
#        form."""
#        tool = instance.portal_types
#        value = {}
#
#        for typeid in field.allowed_types:
#            info = tool.getTypeInfo(typeid)
#            if info is None:
#                raise ValueError, 'No such portal type: %s' % typeid
#
#            value[typeid] = info.Title()
#        return value

    def getDestination(self, instance):
        if not self.destination:
            purl = getToolByName(instance, 'portal_url')
            return purl.getRelativeUrl(aq_parent(instance))
        else:
            value = getattr(aq_base(instance), self.destination,
                            self.destination)
            if callable(value):
                value = value()

            return value

registerWidget(PopupReferenceWidget,
               title='Reference Popup',
               description=('Renders a hidden text area and visible text and button '
                            'which accept a reference value'),
               used_for=('Products.Archetypes.Field.ReferenceField',)
               )
